.. _response:

Responses
=========

.. _response_types:
.. toctree::
   :maxdepth: 1
   :caption: Response Types

   responses/object
   responses/list
   responses/paged_list
   responses/file
   responses/empty
   responses/error
